# hgcroc-tools



## Getting started

This package provides a client to interface with the hexacontroller_sc_server 
and a compatibility layer to run old scripts with the new client.
The documentation lives [here](https://hgcroc-tools.docs.cern.ch/).
